pub unsafe extern "C" fn cef_shutdown()Expand description
This function should be called on the main application thread to shut down the CEF browser process before the application exits.
pub unsafe extern "C" fn cef_shutdown()This function should be called on the main application thread to shut down the CEF browser process before the application exits.