#[repr(C)]pub struct _cef_extension_t {
pub base: cef_base_ref_counted_t,
pub get_identifier: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> cef_string_userfree_t>,
pub get_path: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> cef_string_userfree_t>,
pub get_manifest: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_dictionary_value_t>,
pub is_same: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t, that: *mut _cef_extension_t) -> c_int>,
pub get_handler: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_extension_handler_t>,
pub get_loader_context: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_request_context_t>,
pub is_loaded: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> c_int>,
pub unload: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t)>,
}Expand description
Object representing an extension. Methods may be called on any thread unless otherwise indicated.
Fields
base: cef_base_ref_counted_tBase structure.
get_identifier: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> cef_string_userfree_t>Returns the unique extension identifier. This is calculated based on the extension public key, if available, or on the extension path. See https://developer.chrome.com/extensions/manifest/key for details.
get_path: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> cef_string_userfree_t>Returns the absolute path to the extension directory on disk. This value will be prefixed with PK_DIR_RESOURCES if a relative path was passed to cef_request_context_t::LoadExtension.
get_manifest: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_dictionary_value_t>Returns the extension manifest contents as a cef_dictionary_value_t object. See https://developer.chrome.com/extensions/manifest for details.
is_same: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t, that: *mut _cef_extension_t) -> c_int>Returns true (1) if this object is the same extension as |that| object. Extensions are considered the same if identifier, path and loader context match.
get_handler: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_extension_handler_t>Returns the handler for this extension. Will return NULL for internal extensions or if no handler was passed to cef_request_context_t::LoadExtension.
get_loader_context: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> *mut _cef_request_context_t>Returns the request context that loaded this extension. Will return NULL for internal extensions or if the extension has been unloaded. See the cef_request_context_t::LoadExtension documentation for more information about loader contexts. Must be called on the browser process UI thread.
is_loaded: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t) -> c_int>Returns true (1) if this extension is currently loaded. Must be called on the browser process UI thread.
unload: Option<unsafe extern "C" fn(self_: *mut _cef_extension_t)>Unload this extension if it is not an internal extension and is currently loaded. Will result in a call to cef_extension_handler_t::OnExtensionUnloaded on success.