#[repr(C)]pub struct _cef_v8exception_t {
pub base: cef_base_ref_counted_t,
pub get_message: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>,
pub get_source_line: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>,
pub get_script_resource_name: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>,
pub get_line_number: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>,
pub get_start_position: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>,
pub get_end_position: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>,
pub get_start_column: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>,
pub get_end_column: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>,
}Expand description
Structure representing a V8 exception. The functions of this structure may be called on any render process thread.
Fields
base: cef_base_ref_counted_tBase structure.
get_message: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>Returns the exception message.
get_source_line: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>Returns the line of source code that the exception occurred within.
get_script_resource_name: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> cef_string_userfree_t>Returns the resource name for the script from where the function causing the error originates.
get_line_number: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>Returns the 1-based number of the line where the error occurred or 0 if the line number is unknown.
get_start_position: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>Returns the index within the script of the first character where the error occurred.
get_end_position: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>Returns the index within the script of the last character where the error occurred.
get_start_column: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>Returns the index within the line of the first character where the error occurred.
get_end_column: Option<unsafe extern "C" fn(self_: *mut _cef_v8exception_t) -> c_int>Returns the index within the line of the last character where the error occurred.