pub type cef_dialog_handler_t = _cef_dialog_handler_t;Expand description
Implement this structure to handle dialog events. The functions of this structure will be called on the browser process UI thread.
Aliased Type
#[repr(C)]pub struct cef_dialog_handler_t {
pub base: _cef_base_ref_counted_t,
pub on_file_dialog: Option<unsafe extern "C" fn(*mut _cef_dialog_handler_t, *mut _cef_browser_t, cef_file_dialog_mode_t, *const _cef_string_utf16_t, *const _cef_string_utf16_t, *mut _cef_string_list_t, *mut _cef_file_dialog_callback_t) -> i32>,
}Fields
base: _cef_base_ref_counted_tBase structure.
on_file_dialog: Option<unsafe extern "C" fn(*mut _cef_dialog_handler_t, *mut _cef_browser_t, cef_file_dialog_mode_t, *const _cef_string_utf16_t, *const _cef_string_utf16_t, *mut _cef_string_list_t, *mut _cef_file_dialog_callback_t) -> i32>Called to run a file chooser dialog. |mode| represents the type of dialog to display. |title| to the title to be used for the dialog and may be NULL to show the default title (“Open” or “Save” depending on the mode). |default_file_path| is the path with optional directory and/or file name component that should be initially selected in the dialog. |accept_filters| are used to restrict the selectable file types and may any combination of (a) valid lower-cased MIME types (e.g. “text/” or “image/”), (b) individual file extensions (e.g. “.txt” or “.png”), or (c) combined description and file extension delimited using “|” and “;” (e.g. “Image Types|.png;.gif;.jpg”). To display a custom dialog return true (1) and execute |callback| either inline or at a later time. To display the default dialog return false (0).